@@ -21,6 +21,7 @@ sub build_requires {
     return +{
 	'ExtUtils::MakeMaker'	=> 0,
 	'ExtUtils::Manifest'	=> 0,
+	'File::Find'		=> 0,
 	'File::Copy'		=> 0,
 	'File::Glob'		=> 0,
 	'IO::Compress::Gzip'	=> 0,
@@ -47,20 +48,22 @@ sub requires {
 	'CPAN::Meta'		=> 0,
 	'Cwd'			=> 0,
 	'Digest::SHA'		=> 0,
-	'File::Find'		=> 0,
 	'File::HomeDir'		=> 0,
 	'File::Path'		=> 2.07,
 	'File::Spec'		=> 0,
 	'File::Spec::Unix'	=> 0,
 	'Getopt::Long'		=> 2.33,
 	'HTTP::Date'		=> 0,
+	'HTTP::Response'	=> 0,
 	'IO::File'		=> 0,
 	'IO::Uncompress::Bunzip2'	=> 0,
 	'IO::Uncompress::Gunzip'	=> 0,
+	'LWP::Protocol'			=> 0,
 	'LWP::MediaTypes'		=> 0,
 	'LWP::UserAgent'		=> 0,
 	'Module::Pluggable::Object'	=> 0,
-	'URI::URL'		=> 0,
+	'URI'			=> 0,
+	'URI::file'		=> 0,
 	'Safe'			=> 0,
 	'strict'		=> 0,
 	'Text::ParseWords'	=> 0,
